## Description

<!-- Describe the changes introduced by this PR and the motivation behind them. -->

## Checklist

- [ ] Tests added or updated
- [ ] Docstrings updated for any new or changed public API
- [ ] `CHANGELOG.md` entry added
- [ ] `make fmt` has been run
